/* SFI - Synthesis Fusion Kit Interface
 * Copyright (C) 2002 Tim Janik and Stefan Westerfeld
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __SFI_H__
#define __SFI_H__

/* no bin-compat: #include <sfi/sficomwire.h> */
#include <sfi/sficomport.h>
#include <sfi/sfifilecrawler.h>
#include <sfi/sfiglue.h>
#include <sfi/sfigluecodec.h>
#include <sfi/sfiglueproxy.h>
#include <sfi/sfilog.h>
#include <sfi/sfimemory.h>
#include <sfi/sfinote.h>
#include <sfi/sfiparams.h>
#include <sfi/sfiprimitives.h>
/* #include <sfi/sfisclock.h> */
#include <sfi/sfiserial.h>
#include <sfi/sfithreads.h>
/* no bin-compat: #include <sfi/sfistore.h> */
#include <sfi/sfitime.h>
#include <sfi/sfitypes.h>
#include <sfi/sfiustore.h>
#include <sfi/sfivalues.h>
#include <sfi/sfivmarshal.h>

#endif /* __SFI_VALUE_H__ */

/* vim:set ts=8 sts=2 sw=2: */
